common

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 29, 2026 License: AGPL-3.0-only Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Logger *zap.Logger

Functions

func DecodeJSON

func DecodeJSON[T any](filePath string) (T, error)

func FileNotExists

func FileNotExists(root string) (bool, error)

If an error occurs, the function returns false and the error.

Overwise it answer an empty error coupled with the boolean response to the file inexistance

func InitLogger

func InitLogger(debug bool) error

func MkDirIfNotExists

func MkDirIfNotExists(folderPath string) error

Use FileNotExists to define if the folder exists or not and create it if needed

Types

type FileMetaMap

type FileMetaMap map[string]types.FileMeta

func (FileMetaMap) CheckDependencies

func (fmMap FileMetaMap) CheckDependencies() (bool, map[string][]string)

Get a FileMetaMap and return if some dependencies are missing and the lists with the missing dependency followed by the list of modules inheriting the dependency.

func (FileMetaMap) SetPriorities

func (fmMap FileMetaMap) SetPriorities()

Set priorities on modules for module installation

Directories

Path Synopsis

Jump to