Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Logger *zap.Logger
Functions ¶
func DecodeJSON ¶
func FileNotExists ¶
If an error occurs, the function returns false and the error.
Overwise it answer an empty error coupled with the boolean response to the file inexistance
func InitLogger ¶
func MkDirIfNotExists ¶
Use FileNotExists to define if the folder exists or not and create it if needed
Types ¶
type FileMetaMap ¶
func (FileMetaMap) CheckDependencies ¶
func (fmMap FileMetaMap) CheckDependencies() (bool, map[string][]string)
Get a FileMetaMap and return if some dependencies are missing and the lists with the missing dependency followed by the list of modules inheriting the dependency.
func (FileMetaMap) SetPriorities ¶
func (fmMap FileMetaMap) SetPriorities()
Set priorities on modules for module installation
Click to show internal directories.
Click to hide internal directories.